# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-03-26 05:11
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0018_auto_20180324_1703'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userassignmentimage',
            name='image',
            field=models.ImageField(upload_to='assignments/%Y/%m/%d', verbose_name='\u56fe\u7247\u4f5c\u4e1a'),
        ),
        migrations.AlterField(
            model_name='userassignmentimage',
            name='user_assignment',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.UserAssignment'),
        ),
    ]
