{% extends "bee_django_course/base.html" %}
{% load bootstrap3 %}
{% block content %}

    <h4>添加新课程:</h4>
    <form method="post">
        {% csrf_token %}
        {% bootstrap_form form %}
        {% bootstrap_button '提交' %}
    </form>

    <h4>
        用户{{ user.username }}当前课程
    </h4>
    <table class="table">
        <tr>
            <th>课程</th>
            <th>状态</th>
            <th>课程表</th>
        </tr>
        {% for c in user.usercourse_set.all %}
            <tr>
                <td>{{ c.course.name }}</td>
                <td>
                    {% if c.passed_at %}
                        已通过
                    {% else %}
                        学习中
                    {% endif %}
                </td>
                <td>
                    <a href="{% url 'bee_django_course:user_course_detail' user_course_id=c.id %}">课程表</a>
                </td>
                <td>
                    {% if not c.passed_at %}
                        <a href="#" data-confirm="{% url 'bee_django_course:delete_user_course' user_course_id=c.id %}" class="confirm">
                            删除
                        </a>
                    {% endif %}
                </td>
            </tr>
        {% endfor %}
    </table>


    <script type="text/javascript">
        $(document).ready(function () {
            $('.confirm').click(function () {
                if (confirm('!!!!!此操作将删除分配给用户的课程，以及此课程下所有章节的学习记录!!!!!是否继续?')) {
                    var url = $(this).attr('data-confirm');
                    $.post(url)
                        .done(function (data) {
                            window.location.href = data['success_url'];
                        })
                        .fail(function () {
                            alert("删除错误");
                        });
                }
            });
        });
    </script>


{% endblock content %}