# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-08 10:46
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0005_auto_20180108_1640'),
    ]

    operations = [
        migrations.CreateModel(
            name='Video',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('video_id', models.CharField(max_length=180, null=True)),
                ('status', models.CharField(max_length=180, null=True)),
                ('duration', models.CharField(max_length=180, null=True)),
                ('image', models.CharField(max_length=180, null=True)),
                ('title', models.CharField(max_length=180, null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
            ],
            options={
                'ordering': ['-created_at'],
                'db_table': 'bee_django_course_video',
            },
        ),
        migrations.AlterModelOptions(
            name='coursesectionmid',
            options={'ordering': ['order_by']},
        ),
        migrations.AddField(
            model_name='section',
            name='videos',
            field=models.ManyToManyField(to='bee_django_course.Video'),
        ),
    ]
