{% extends "bee_django_course/base.html" %}
{% block content %}
    <h4>视频详情</h4>
    <div>
        <iframe src="{{ video_src }}" frameborder="0" width="100%" height="100%"></iframe>
    </div>
    {#    <a href="{% url 'bee_django_course:video_update'  video.id %}">修改视频信息</a>#}
    {#    <table class="table">#}
    {#        <tr>#}
    {#            <td>视频</td>#}
    {#            <td><iframe src="{{ video_src }}" frameborder="0" width="100%" height="40%"></iframe></td>#}
    {#        </tr>#}
    {#        <tr>#}
    {#            <td class="col-xs-3">标题</td>#}
    {#            <td>{{ video.name }}</td>#}
    {#        </tr>#}
    {#    </table>#}
    <h4>说明：</h4>
    <div>
        {{ video.info | default:'' | linebreaks }}
    </div>
{% endblock %}