{% extends 'bee_django_course/base.html' %}
{% load bootstrap3 %}

{% block content %}
    <div class="col-md-6">
        <form method="post">
            {% csrf_token %}
            {% bootstrap_form form %}
            {% bootstrap_button '保存' %}
        </form>
    </div>
{% endblock content %}