# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-25 10:41
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0041_userlive_coin_multiple'),
    ]

    operations = [
        migrations.AddField(
            model_name='section',
            name='auto_pass',
            field=models.BooleanField(default=False),
        ),
    ]
