# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-03-30 07:13
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0022_sectionvideo'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='course',
            options={'ordering': ['-id'], 'permissions': (('can_choose_course', 'can choose course'),)},
        ),
    ]
