# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-26 05:24
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0043_auto_20180625_1928'),
    ]

    operations = [
        migrations.AddField(
            model_name='sectionvideo',
            name='order',
            field=models.IntegerField(default=0, verbose_name='\u5728\u8bfe\u4ef6\u91cc\u7684\u6392\u5e8f'),
        ),
    ]
