# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-03-20 03:19
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0011_auto_20180318_1618'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='section',
            name='order_by',
        ),
    ]
