# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-05-16 09:14
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0030_preference'),
    ]

    operations = [
        migrations.AddField(
            model_name='video',
            name='info',
            field=models.TextField(blank=True, null=True, verbose_name='\u8bf4\u660e'),
        ),
        migrations.AlterField(
            model_name='video',
            name='title',
            field=models.CharField(max_length=180, null=True, verbose_name='\u6807\u9898'),
        ),
    ]
